@@ -6,20 +6,20 @@
 #' \preformatted{
 #' Dict$new()
 #' Dict$set(key, value)
-#' Dict$get(key, default = NULL)
+#' Dict$get(key)
 #' Dict$remove(key)
-#' Dict$pop(key, default = NULL)
+#' Dict$pop(key)
 #' Dict$has(key)
 #' Dict$keys()
 #' Dict$values()
 #' Dict$update(d)
+#' Dict$clear()
 #' Dict$size()
 #' Dict$as_list()
 #' }
 #' @section Usage:
 #' * `key`: any R object, key of the item
 #' * `value`: any R object, value of the item
-#' * `default`: the default value of an item if the key is not found
 #' @examples
 #' d <- Dict$new()
 #' d$set("apple", 5)
@@ -38,20 +38,20 @@ Dict <- R6::R6Class("Dict",
     ),
     public = list(
         initialize = function() {
-            private$e <- new.env(hash = TRUE)
+            self$clear()
         },
         set = function(key, value) {
             assign(key, value, envir = private$e)
         },
-        get = function(key, default = NULL) {
-            .Call("dict_get", PACKAGE = "collections", private$e, key, default)
+        get = function(key) {
+            .Call("dict_get", PACKAGE = "collections", private$e, key)
         },
         remove = function(key) {
             .Internal(remove(key, private$e, FALSE))
             invisible(NULL)
         },
-        pop = function(key, default = NULL) {
-            v <- self$get(key, default)
+        pop = function(key) {
+            v <- self$get(key)
             self$remove(key)
             v
         },
@@ -70,6 +70,9 @@ Dict <- R6::R6Class("Dict",
             }
             self
         },
+        clear = function() {
+            private$e <- new.env(hash = TRUE)
+        },
         size = function() length(ls(private$e)),
         as_list = function() as.list(private$e)
     )
