@@ -6,21 +6,21 @@
 #' \preformatted{
 #' OrderedDict$new()
 #' OrderedDict$set(key, value)
-#' OrderedDict$get(key, default = NULL)
+#' OrderedDict$get(key)
 #' OrderedDict$remove(key)
-#' OrderedDict$pop(key, default = NULL)
-#' OrderedDict$popitem(last = TRUE, default = NULL)
+#' OrderedDict$pop(key)
+#' OrderedDict$popitem(last = TRUE)
 #' OrderedDict$has(key)
 #' OrderedDict$keys()
 #' OrderedDict$values()
 #' OrderedDict$update(d)
+#' OrderedDict$clear()
 #' OrderedDict$size()
 #' OrderedDict$as_list()
 #' }
 #' @section Argument:
 #' * `key`: any R object, key of the item
 #' * `value`: any R object, value of the item
-#' * `default`: the default value of an item if the key is not found
 #' * `d`: an OrderedDict or OrderedDictL
 #' @examples
 #' d <- OrderedDict$new()
@@ -41,33 +41,32 @@ OrderedDict <- R6::R6Class("OrderedDict",
     ),
     public = list(
         initialize = function() {
-            private$e <- new.env(hash = TRUE)
-            private$q <- Deque$new()
+            self$clear()
         },
         set = function(key, value) {
             private$q$push(key)
             assign(key, value, envir = private$e)
         },
-        get = function(key, default = NULL) {
-            .Call("dict_get", PACKAGE = "collections", private$e, key, default)
+        get = function(key) {
+            .Call("dict_get", PACKAGE = "collections", private$e, key)
         },
         remove = function(key) {
             private$q$remove(key)
             .Internal(remove(key, private$e, FALSE))
             invisible(NULL)
         },
-        pop = function(key, default = NULL) {
-            v <- self$get(key, default)
+        pop = function(key) {
+            v <- self$get(key)
             self$remove(key)
             v
         },
-        popitem = function(last = TRUE, default = NULL) {
+        popitem = function(last = TRUE) {
             if (last) {
                 key <- private$q$pop()
             } else {
                 key <- private$q$popleft()
             }
-            v <- self$get(key, default)
+            v <- self$get(key)
             .Internal(remove(key, private$e, FALSE))
             list(key = key, value = v)
         },
@@ -92,6 +91,10 @@ OrderedDict <- R6::R6Class("OrderedDict",
             }
             self
         },
+        clear = function() {
+            private$e <- new.env(hash = TRUE)
+            private$q <- Deque$new()
+        },
         size = function() length(ls(private$e)),
         as_list = function() {
             ret <- list()
@@ -106,27 +109,27 @@ OrderedDict <- R6::R6Class("OrderedDict",
 #' @title Ordered Dictionary (list based)
 #' @description
 #' The `OrderedDictL` class creates an ordered dictionary.
-#' The key-value pairs are stored in an R environment.
+#' The key-value pairs are stored in an R List.
 #' Pure R implementation, mainly for benchmark.
 #' @section Usage:
 #' \preformatted{
 #' OrderedDictL$new()
 #' OrderedDictL$set(key, value)
-#' OrderedDictL$get(key, default = NULL)
+#' OrderedDictL$get(key)
 #' OrderedDictL$remove(key)
-#' OrderedDictL$pop(key, default = NULL)
-#' OrderedDict$popitem(last = TRUE, default = NULL)
+#' OrderedDictL$pop(key)
+#' OrderedDict$popitem(last = TRUE)
 #' OrderedDictL$has(key)
 #' OrderedDictL$keys()
 #' OrderedDictL$values()
 #' OrderedDictL$update(d)
+#' OrderedDictL$clear()
 #' OrderedDictL$size()
 #' OrderedDictL$as_list()
 #' }
 #' @section Argument:
 #' * `key`: any R object, key of the item
 #' * `value`: any R object, value of the item
-#' * `default`: the default value of an item if the key is not found
 #' * `d`: an OrderedDict or OrderedDictL
 #' @examples
 #' d <- OrderedDictL$new()
@@ -142,17 +145,20 @@ OrderedDict <- R6::R6Class("OrderedDict",
 OrderedDictL <- R6::R6Class("OrderedDictL",
     cloneable = FALSE,
     private = list(
-        e = list()
+        e = NULL
     ),
     public = list(
+        initialize = function() {
+            self$clear()
+        },
         set = function(key, value) {
             private$e[[key]] <- value
         },
-        get = function(key, default = NULL) {
+        get = function(key) {
             if (self$has(key)) {
                 private$e[[key]]
             } else {
-                default
+                stop("key not found")
             }
         },
         remove = function(key) {
@@ -161,19 +167,19 @@ OrderedDictL <- R6::R6Class("OrderedDictL",
             private$e <- private$e[v]
             invisible(NULL)
         },
-        pop = function(key, default = NULL) {
-            v <- self$get(key, default)
+        pop = function(key) {
+            v <- self$get(key)
             self$remove(key)
             v
         },
-        popitem = function(last = TRUE, default = NULL) {
+        popitem = function(last = TRUE) {
             if (last) {
                 keys <- self$keys()
                 key <- key[length(keys)]
             } else {
                 keys <- self$keys()[1]
             }
-            v <- self$get(key, default)
+            v <- self$get(key)
             self$remove(key)
             list(key = key, vlaue = v)
         },
@@ -198,6 +204,9 @@ OrderedDictL <- R6::R6Class("OrderedDictL",
             }
             self
         },
+        clear = function() {
+            private$e <- list()
+        },
         size = function() length(private$e),
         as_list = function() private$e
     )
