@@ -15,6 +15,15 @@ test_that("push and pop", {
     expect_error(s$pop(), "empty")
 })
 
+test_that("clear", {
+    s <- Stack$new()
+    s$push("a")
+    s$push("b")
+    s$push("c")
+    s$clear()
+    expect_equal(s$size(), 0)
+})
+
 
 context("StackL")
 
@@ -32,3 +41,12 @@ test_that("push and pop", {
     expect_equal(s$size(), 0)
     expect_error(s$pop(), "empty")
 })
+
+test_that("clear", {
+    s <- StackL$new()
+    s$push("a")
+    s$push("b")
+    s$push("c")
+    s$clear()
+    expect_equal(s$size(), 0)
+})
